# Cornerpool

![Build](https://github.com/bishwarup307/cornerpool/workflows/Build/badge.svg)

Cornerpool is a small python utility for *corner pooling* as originally introducted in the [CornerNet paper](https://arxiv.org/abs/1808.01244)

## Installation

